==> ksystemlog-18.07.80.tar.xz: ksystemlog-18.07.80/src/modes/cups/cupsPageLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _CUPS_PAGE_LOG_MODE_H_
#define _CUPS_PAGE_LOG_MODE_H_

/**
 * Cups Page Log Mode Identifier
 */
#define CUPS_PAGE_LOG_MODE_ID "cupsPageLogMode"

/**
 * Cups Page Log Icon
 */
#define CUPS_PAGE_MODE_ICON "document-new"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class CupsConfiguration;
class CupsConfigurationWidget;

class CupsPageLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit CupsPageLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration,
                             CupsConfigurationWidget *cupsConfigurationWidget);

    ~CupsPageLogMode();

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;

    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
};

#endif // _CUPS_PAGE_LOG_MODE_H_

==> ksystemlog-21.04.1.tar.xz: ksystemlog-21.04.1/src/modes/cups/cupsPageLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef CUPS_PAGE_LOG_MODE_H
#define CUPS_PAGE_LOG_MODE_H

/**
 * Cups Page Log Mode Identifier
 */
#define CUPS_PAGE_LOG_MODE_ID "cupsPageLogMode"

/**
 * Cups Page Log Icon
 */
#define CUPS_PAGE_MODE_ICON "document-new"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class CupsConfiguration;
class CupsConfigurationWidget;

class CupsPageLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit CupsPageLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration, CupsConfigurationWidget *cupsConfigurationWidget);

    ~CupsPageLogMode() override;

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;

    QVector<LogFile> createLogFiles() override;
};

#endif // _CUPS_PAGE_LOG_MODE_H
